# Generated by Django 4.2.5 on 2023-09-22 13:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('diary', '0009_resource_bg_color_resource_fg_color'),
    ]

    operations = [
        migrations.AddField(
            model_name='resource',
            name='enabled',
            field=models.BooleanField(default=True),
        ),
        migrations.AlterField(
            model_name='resource',
            name='bg_color',
            field=models.CharField(choices=[('Black', 'Black'), ('White', 'White'), ('Silver', 'Silver'), ('LightGrey', 'Light Grey'), ('DarkGrey', 'Dark Grey'), ('Red', 'Red'), ('Crimson', 'Crimson'), ('DarkRed', 'Dark Red'), ('Magenta', 'Magenta'), ('DarkMagenta', 'Dark Magenta'), ('Green', 'Green'), ('LightGreen', 'Light Green'), ('DarkGreen', 'Dark Green'), ('YellowGreen', 'Yellow Green'), ('Blue', 'Blue'), ('LightBlue', 'Light Blue'), ('DarkBlue', 'Dark Blue'), ('RoyalBlue', 'Royal Blue'), ('Teal', 'Teal'), ('Yellow', 'Yellow'), ('LightYellow', 'Light Yellow'), ('Gold', 'Gold'), ('GoldenRod', 'Golden Rod'), ('LightGoldenRodYellow', 'Light Golden Rod Yellow'), ('DarkGoldenRod', 'Dark Golden Rod'), ('Brown', 'Brown'), ('Tan', 'Tan'), ('SandyBrown', 'Sandy Brown'), ('Pink', 'Pink'), ('LightPink', 'Light Pink'), ('Salmon', 'Salmon'), ('LightSalmon', 'Light Salmon'), ('Purple', 'Purple'), ('Violet', 'Violet'), ('PaleVioletRed', 'Pale Violet Red'), ('DarkViolet', 'Dark Violet')], default='White', max_length=20),
        ),
        migrations.AlterField(
            model_name='resource',
            name='fg_color',
            field=models.CharField(choices=[('Black', 'Black'), ('White', 'White'), ('Silver', 'Silver'), ('LightGrey', 'Light Grey'), ('DarkGrey', 'Dark Grey'), ('Red', 'Red'), ('Crimson', 'Crimson'), ('DarkRed', 'Dark Red'), ('Magenta', 'Magenta'), ('DarkMagenta', 'Dark Magenta'), ('Green', 'Green'), ('LightGreen', 'Light Green'), ('DarkGreen', 'Dark Green'), ('YellowGreen', 'Yellow Green'), ('Blue', 'Blue'), ('LightBlue', 'Light Blue'), ('DarkBlue', 'Dark Blue'), ('RoyalBlue', 'Royal Blue'), ('Teal', 'Teal'), ('Yellow', 'Yellow'), ('LightYellow', 'Light Yellow'), ('Gold', 'Gold'), ('GoldenRod', 'Golden Rod'), ('LightGoldenRodYellow', 'Light Golden Rod Yellow'), ('DarkGoldenRod', 'Dark Golden Rod'), ('Brown', 'Brown'), ('Tan', 'Tan'), ('SandyBrown', 'Sandy Brown'), ('Pink', 'Pink'), ('LightPink', 'Light Pink'), ('Salmon', 'Salmon'), ('LightSalmon', 'Light Salmon'), ('Purple', 'Purple'), ('Violet', 'Violet'), ('PaleVioletRed', 'Pale Violet Red'), ('DarkViolet', 'Dark Violet')], default='Black', max_length=20),
        ),
    ]
