# Generated by Django 4.2.5 on 2023-09-21 13:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('diary', '0008_customer_opt_out_entry_change_email_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='resource',
            name='bg_color',
            field=models.CharField(choices=[('Black', 'Black'), ('White', 'White'), ('Red', 'Red'), ('Green', 'Green'), ('Blue', 'Blue'), ('Yellow', 'Yellow'), ('Pink', 'Pink')], default='White', max_length=20),
        ),
        migrations.AddField(
            model_name='resource',
            name='fg_color',
            field=models.CharField(choices=[('Black', 'Black'), ('White', 'White'), ('Red', 'Red'), ('Green', 'Green'), ('Blue', 'Blue'), ('Yellow', 'Yellow'), ('Pink', 'Pink')], default='Black', max_length=20),
        ),
    ]
